@@ -6,7 +6,7 @@ import pytest
 
 from astropy import units as u
 
-asdf = pytest.importorskip('asdf')
+asdf = pytest.importorskip('asdf', minversion='2.0.0')
 from asdf.tests import helpers
 
 
