@@ -5,17 +5,10 @@ Tests for model evaluation.
 Compare the results of some models with other programs.
 """
 
-
-
-try:
-    import cPickle as pickle
-except ImportError:
-    import pickle
-
 import pytest
 import numpy as np
 
-from numpy.testing import utils
+from numpy.testing import assert_allclose, assert_equal
 
 from .example_models import models_1D, models_2D
 from .. import fitting, models
@@ -243,8 +236,8 @@ class Fittable2DModelTester:
                              if not fixed])
         fitted = np.array([param.value for param in params
                            if not param.fixed])
-        utils.assert_allclose(fitted, expected,
-                              atol=self.fit_error)
+        assert_allclose(fitted, expected,
+                        atol=self.fit_error)
 
     @pytest.mark.skipif('not HAS_SCIPY')
     def test_deriv_2D(self, model_class, test_parameters):
@@ -300,9 +293,9 @@ class Fittable2DModelTester:
         fitter_no_deriv = fitting.LevMarLSQFitter()
         new_model_no_deriv = fitter_no_deriv(model_no_deriv, xv, yv, data,
                                              estimate_jacobian=True)
-        utils.assert_allclose(new_model_with_deriv.parameters,
-                              new_model_no_deriv.parameters,
-                              rtol=0.1)
+        assert_allclose(new_model_with_deriv.parameters,
+                        new_model_no_deriv.parameters,
+                        rtol=0.1)
 
 
 class Fittable1DModelTester:
@@ -343,7 +336,7 @@ class Fittable1DModelTester:
         model = create_model(model_class, test_parameters)
         x = test_parameters['x_values']
         y = test_parameters['y_values']
-        utils.assert_allclose(model(x), y, atol=self.eval_error)
+        assert_allclose(model(x), y, atol=self.eval_error)
 
     def test_bounding_box1D(self, model_class, test_parameters):
         """Test bounding box evaluation"""
@@ -417,7 +410,7 @@ class Fittable1DModelTester:
                              if not fixed])
         fitted = np.array([param.value for param in params
                            if not param.fixed])
-        utils.assert_allclose(fitted, expected, atol=self.fit_error)
+        assert_allclose(fitted, expected, atol=self.fit_error)
 
     @pytest.mark.skipif('not HAS_SCIPY')
     def test_deriv_1D(self, model_class, test_parameters):
@@ -455,8 +448,8 @@ class Fittable1DModelTester:
         fitter_no_deriv = fitting.LevMarLSQFitter()
         new_model_no_deriv = fitter_no_deriv(model_no_deriv, x, data,
                                              estimate_jacobian=True)
-        utils.assert_allclose(new_model_with_deriv.parameters,
-                              new_model_no_deriv.parameters, atol=0.15)
+        assert_allclose(new_model_with_deriv.parameters,
+                        new_model_no_deriv.parameters, atol=0.15)
 
 
 def create_model(model_class, test_parameters, use_constraints=True,
@@ -491,26 +484,26 @@ def test_ShiftModel():
     # Shift by a scalar
     m = models.Shift(42)
     assert m(0) == 42
-    utils.assert_equal(m([1, 2]), [43, 44])
+    assert_equal(m([1, 2]), [43, 44])
 
     # Shift by a list
     m = models.Shift([42, 43], n_models=2)
-    utils.assert_equal(m(0), [42, 43])
-    utils.assert_equal(m([1, 2], model_set_axis=False),
-                       [[43, 44], [44, 45]])
+    assert_equal(m(0), [42, 43])
+    assert_equal(m([1, 2], model_set_axis=False),
+                 [[43, 44], [44, 45]])
 
 
 def test_ScaleModel():
     # Scale by a scalar
     m = models.Scale(42)
     assert m(0) == 0
-    utils.assert_equal(m([1, 2]), [42, 84])
+    assert_equal(m([1, 2]), [42, 84])
 
     # Scale by a list
     m = models.Scale([42, 43], n_models=2)
-    utils.assert_equal(m(0), [0, 0])
-    utils.assert_equal(m([1, 2], model_set_axis=False),
-                       [[42, 84], [43, 86]])
+    assert_equal(m(0), [0, 0])
+    assert_equal(m([1, 2], model_set_axis=False),
+                 [[42, 84], [43, 86]])
 
 
 def test_voigt_model():
@@ -541,10 +534,10 @@ def test_tabular_interp_1d():
     model = LookupTable(points=points, lookup_table=values)
     xnew = [0., .7, 1.4, 2.1, 3.9]
     ans1 = [1., 7.3, 6.8, 6.3, 1.8]
-    utils.assert_allclose(model(xnew), ans1)
+    assert_allclose(model(xnew), ans1)
     # Test evaluate without passing `points`.
     model = LookupTable(lookup_table=values)
-    utils.assert_allclose(model(xnew), ans1)
+    assert_allclose(model(xnew), ans1)
     # Test bounds error.
     xextrap = [0., .7, 1.4, 2.1, 3.9, 4.1]
     with pytest.raises(ValueError):
@@ -552,8 +545,8 @@ def test_tabular_interp_1d():
     # test extrapolation and fill value
     model = LookupTable(lookup_table=values, bounds_error=False,
                         fill_value=None)
-    utils.assert_allclose(model(xextrap),
-                          [1., 7.3, 6.8, 6.3, 1.8, -7.8])
+    assert_allclose(model(xextrap),
+                    [1., 7.3, 6.8, 6.3, 1.8, -7.8])
 
     # Test unit support
     xnew = xnew * u.nm
@@ -588,14 +581,14 @@ def test_tabular_interp_2d():
     znew = model(xnew, xnew)
     result = np.array(
         [-0.04614432, -0.03450009, -0.02241028, -0.0069727, 0.01938675])
-    utils.assert_allclose(znew, result, atol=1e-7)
+    assert_allclose(znew, result, atol=1e-7)
 
     # test 2D arrays as input
     a = np.arange(12).reshape((3, 4))
     y, x = np.mgrid[:3, :4]
     t = models.Tabular2D(lookup_table=a)
     r = t(y, x)
-    utils.assert_allclose(a, r)
+    assert_allclose(a, r)
 
     with pytest.raises(ValueError):
         model = LookupTable(points=([1.2, 2.3], [1.2, 6.7], [3, 4]))
@@ -632,7 +625,7 @@ def test_tabular_nd():
     tab = models.tabular_model(3)
     t = tab(lookup_table=a)
     result = t(x, y, z)
-    utils.assert_allclose(a, result)
+    assert_allclose(a, result)
 
     with pytest.raises(ValueError):
         models.tabular_model(0)
@@ -653,13 +646,13 @@ def test_with_bounding_box():
     a, b = m(x, y)
     aw, bw = m(x, y, with_bounding_box=True)
     ind = (~np.isnan(aw)).nonzero()
-    utils.assert_allclose(a[ind], aw[ind])
-    utils.assert_allclose(b[ind], bw[ind])
+    assert_allclose(a[ind], aw[ind])
+    assert_allclose(b[ind], bw[ind])
 
     aw, bw = m(x, y, with_bounding_box=True, fill_value=1000)
     ind = (aw != 1000).nonzero()
-    utils.assert_allclose(a[ind], aw[ind])
-    utils.assert_allclose(b[ind], bw[ind])
+    assert_allclose(a[ind], aw[ind])
+    assert_allclose(b[ind], bw[ind])
 
     # test the order of bbox is not reversed for 1D models
     p = models.Polynomial1D(1, c0=12, c1=2.3)
