@@ -9,7 +9,7 @@ from collections import OrderedDict
 
 import pytest
 import numpy as np
-from numpy.testing import assert_allclose
+from numpy.testing import assert_allclose, assert_array_equal
 
 from ...io import fits
 from ...tests.helper import (assert_follows_unicode_guidelines,
@@ -1650,6 +1650,11 @@ class TestPandas:
         t['s'] = ['a', 'b', 'c']
         t['s'].mask = [False, True, False]
 
+        # https://github.com/astropy/astropy/issues/7741
+        t['Source'] = [2584290278794471936, 2584290038276303744,
+                       2584288728310999296]
+        t['Source'].mask = [False, False, False]
+
         d = t.to_pandas()
 
         t2 = table.Table.from_pandas(d)
@@ -1659,7 +1664,12 @@ class TestPandas:
             assert np.all(column.mask == t2[name].mask)
             # Masked integer type comes back as float.  Nothing we can do about this.
             if column.dtype.kind == 'i':
-                assert t2[name].dtype.kind == 'f'
+                if np.any(column.mask):
+                    assert t2[name].dtype.kind == 'f'
+                else:
+                    assert t2[name].dtype.kind == 'i'
+                assert_array_equal(column.data,
+                                   t2[name].data.astype(column.dtype))
             else:
                 if column.dtype.byteorder in ('=', '|'):
                     assert column.dtype == t2[name].dtype
