@@ -2,13 +2,11 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Separate tests specifically for equivalencies."""
 
-
-
 # THIRD-PARTY
 import warnings
 import pytest
 import numpy as np
-from numpy.testing.utils import assert_allclose
+from numpy.testing import assert_allclose
 
 # LOCAL
 from ... import units as u
