@@ -388,10 +388,22 @@ class CoordinateHelper:
             can include keywords to set the ``color``, ``size``, ``weight``, and
             other text properties.
         """
+
+        fontdict = kwargs.pop('fontdict', None)
+
+        # NOTE: When using plt.xlabel/plt.ylabel, minpad can get set explicitly
+        # to None so we need to make sure that in that case we change to a
+        # default numerical value.
+        if minpad is None:
+            minpad = 1
+
         self.axislabels.set_text(text)
         self.axislabels.set_minpad(minpad)
         self.axislabels.set(**kwargs)
 
+        if fontdict is not None:
+            self.axislabels.update(fontdict)
+
     def get_axislabel(self):
         """
         Get the text for the axis label
@@ -769,14 +781,19 @@ class CoordinateHelper:
         xmin, xmax = self.parent_axes.get_xlim()
         ymin, ymax = self.parent_axes.get_ylim()
 
-        x, y, field = self.transform.get_coord_slices(xmin, xmax, ymin, ymax, 200, 200)
+        from . import conf
+        res = conf.contour_grid_samples
+
+        x, y = np.meshgrid(np.linspace(xmin, xmax, res),
+                           np.linspace(ymin, ymax, res))
+        pixel = np.array([x.ravel(), y.ravel()]).T
+        world = self.transform.transform(pixel)
+        field = world[:, self.coord_index].reshape(res, res).T
 
         coord_range = self.parent_map.get_coord_range()
 
         tick_world_coordinates, spacing = self.locator(*coord_range[self.coord_index])
 
-        field = field[self.coord_index]
-
         # tick_world_coordinates is a Quantities array and we only needs its values
         tick_world_coordinates_values = tick_world_coordinates.value
 
